Calibration
===========

The `PDFstream` do not have the calibration tools. Please use
`pyFAI-calib2 <https://pyfai.readthedocs.io/en/master/usage/cookbook/calib-gui/index.html>`_
to calibrate the instrumental setup. The result will be in the .poni file.
